==> krita-3.1.1.tar.gz: krita-3.1.1/libs/flake/tools/KoCreateShapeStrategy.h <==
/* This file is part of the KDE project
 * Copyright (C) 2006 Thomas Zander <zander@kde.org>
 * Copyright (C) 2006 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KOCREATESHAPESTRATEGY_H
#define KOCREATESHAPESTRATEGY_H

#include "KoShapeRubberSelectStrategy.h"

#include <QPointF>
#include <QPainterPath>

class KoCreateShapesTool;

/**
 * A strategy for the KoCreateShapesTool.
 */
class KoCreateShapeStrategy : public KoShapeRubberSelectStrategy
{
public:
    /**
     * Constructor that starts to create a new shape.
     * @param tool the parent tool which controls this strategy
     * @param clicked the initial point that the user depressed (in pt).
     */
    KoCreateShapeStrategy(KoCreateShapesTool *tool, const QPointF &clicked);
    virtual ~KoCreateShapeStrategy() {}

    void finishInteraction(Qt::KeyboardModifiers modifiers);
    KUndo2Command* createCommand();
    void paint(QPainter &painter, const KoViewConverter &converter);
    void handleMouseMove(const QPointF &mouseLocation, Qt::KeyboardModifiers modifiers);

private:
    QPainterPath m_outline;
    QRectF m_outlineBoundingRect;
    Q_DECLARE_PRIVATE(KoShapeRubberSelectStrategy)
};

#endif

==> krita_4.1.5+dfsg.orig.tar.gz: krita-4.1.5/libs/flake/tools/KoCreateShapeStrategy.h <==
/* This file is part of the KDE project
 * Copyright (C) 2006 Thomas Zander <zander@kde.org>
 * Copyright (C) 2006 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KOCREATESHAPESTRATEGY_H
#define KOCREATESHAPESTRATEGY_H

#include "KoShapeRubberSelectStrategy.h"

#include <QPointF>
#include <QPainterPath>

class KoCreateShapesTool;

/**
 * A strategy for the KoCreateShapesTool.
 */
class KoCreateShapeStrategy : public KoShapeRubberSelectStrategy
{
public:
    /**
     * Constructor that starts to create a new shape.
     * @param tool the parent tool which controls this strategy
     * @param clicked the initial point that the user depressed (in pt).
     */
    KoCreateShapeStrategy(KoCreateShapesTool *tool, const QPointF &clicked);
    ~KoCreateShapeStrategy() override {}

    void finishInteraction(Qt::KeyboardModifiers modifiers) override;
    KUndo2Command* createCommand() override;
    void paint(QPainter &painter, const KoViewConverter &converter) override;
    void handleMouseMove(const QPointF &mouseLocation, Qt::KeyboardModifiers modifiers) override;

private:
    QPainterPath m_outline;
    QRectF m_outlineBoundingRect;
    Q_DECLARE_PRIVATE(KoShapeRubberSelectStrategy)
};

#endif
